==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/sql_history/translations/sql_history_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click Me !1!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose database type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose type of databse, in which data should be stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SQLite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MySQL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PostgreSQL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table name prefix</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database.
 Please select another driver in configuration window or install Qt with %1 plugin.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/sql_history/translations/sql_history_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click Me !1!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose database type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose type of databse, in which data should be stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SQLite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MySQL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PostgreSQL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table name prefix</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optimizing history database. This can take several minutes.
Please do not close Kadu until optimalization is complete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optimalization complete. You can now close this window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optimalization failed. Error message:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
